load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRFUserARW.ncl"

begin

;============================================================================== 
; map resource
;------------------------------------------------------------------------------
  shape  = "/home/sjpark/work/results/shapefiles/TL_SCCO_CTPRVN.shp"
  shape1 = "/home/sjpark/work/results/shapefiles/KOR_adm1.shp"
  shape2 = "/home/sjpark/work/results/shapefiles/PRK_adm0.shp"

  ;type = "x11"
  type = "png"
  type@wkWidth  = 1000
  type@wkHeight = 1000

  res = True
  res@lbBoxLinesOn              = False
  res@Footer = False
  res@InitTime = False

  pltres = True
  pltres@NoTitles = True
  pltres@PanelPlot  = True   ; Tells wrf_map_overlays not to remove overlays

  mpres = True
  mpres@mpOutlineBoundarySets       = "NoBoundaries" ;; turns on country boundaries
  mpres@mpDataSetName               = "Earth..4"
  mpres@mpGeophysicalLineColor      = "Black"
  mpres@mpNationalLineColor         = "Black"
  mpres@mpUSStateLineColor          = "Black"
  mpres@mpGridLineColor             = "Gray"
  mpres@mpLimbLineColor             = "Black"
  mpres@mpPerimLineColor            = "Black"
  mpres@mpGeophysicalLineThicknessF = 2.0
  mpres@mpGridLineThicknessF        = 0.0
  mpres@mpLimbLineThicknessF        = 2.0
  mpres@mpNationalLineThicknessF    = 2.0
  mpres@mpUSStateLineThicknessF     = 2.0
  mpres@mpGridLineDashPattern       = 2
  mpres@mpGridLatSpacingF           = 1
  mpres@mpGridLonSpacingF           = 1
  mpres@mpOutlineOn = True;False  ; Turn off map outlines
  mpres@mpFillOn    = False  ; Turn off map fill
;=========================================================================================

  ifil = "wrfout_d02_2018-08-06_00:00:00"
  bifil = "wrfout_d02_2018-08-05_12:00:00"

idir = "/home/sjpark/work/results/" ;;change

; The WRF ARW input file.  
  a = addfile(idir+ifil,"r")
  b = addfile(idir+bifil,"r")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; What times and how many time steps are in the data set?
  times = wrf_user_getvar(a,"times",-1)  ; get all times in the file
  ntimes = dimsizes(times); number of times in the file
  it = 0
  print("Working on time: " + times(it) )
  time = times(it)

  lat=wrf_user_getvar(a,"XLAT",0)
  lon=wrf_user_getvar(a,"XLONG",0)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; First get the variables we will need        
  rain = wrf_user_getvar(a,"RAINC",it)     ; Accumulated total cumulus precipitation (mm)
  crain = wrf_user_getvar(a,"RAINNC",it)     ; Accumulated total grid scale precipitation(mm)
  rain_plane = rain+crain

  brain = wrf_user_getvar(b,"RAINC",it)     ; Accumulated total cumulus precipitation (mm)
  bcrain = wrf_user_getvar(b,"RAINNC",it)     ; Accumulated total grid scale precipitation(mm)
  brain_plane = brain+bcrain
  rain_plane = rain_plane - brain_plane
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Plotting options for RAIN
  odir = "./"
  wks = gsn_open_wks(type,odir+"/OPT_ACC_12hourly_PRCP_080513-080600")
  gsn_define_colormap(wks,"kma_prcp_191001")

  opts = res
  opts@cnFillOn                 = True
  opts@cnLinesOn              = False            ; turn off contour lines
  opts@cnLineLabelsOn         = False            ; turn off contour labels
  opts@cnLevelSelectionMode = "ExplicitLevels" ; set explicit contour levels

  opts@cnLevels    = (/ 0.01, 0.1, 0.5, 1.0, 2.0, 3.0, 4.0, 5.0, \
              6.0, 7.0, 8.0, 9.0, 10., 15., 20., \
              25., 30., 40., 50., 60., 70., 80., 90., 110. /)


  opts@lbOrientation =   "vertical"          ; vertical label bar

  opts@pmLabelBarOrthogonalPosF = -1.05
  opts@pmLabelBarParallelPosF = 1.2

  opts@cnInfoLabelString    = "Min= $ZMN$ Max= $ZMX$"
  opts@cnInfoLabelOrthogonalPosF = -0.104        ; move info label into plot
  contour_rain = wrf_contour(a,wks,rain_plane,opts)
  delete(opts)
  plot = wrf_map_overlays(a,wks,(/contour_rain/),pltres,mpres)

;------ city boundary-------------------------------------------
  poly = gsn_add_shapefile_polylines(wks,plot,shape1,mpres)
  poly2 = gsn_add_shapefile_polylines(wks,plot,shape2,mpres)
;---------------------------------------------------------------

;-------station location----------------------------------------
  slon  = (/ 128.56, 128.89, 128.72 /) ;sokcho, gangneung, daegwallyeon
  slat  = (/  38.25,  37.75, 37.68 /)
  sname = (/"Sokcho", "Gangeung", "Daegwallyeong"/)

  mkres   = True
  mkres@gsMarkerIndex = 16
  mkres@gsMarkerSizeF = 0.007
  mkres@gsMarkerThicknessF = 2
  mkres@gsLineThicknessF = 4
  mkres@gsMarkerColor = "black"
  mkid  = gsn_add_polymarker(wks,plot,slon,slat,mkres)

  txres                       = True
  txres@txFontHeightF         = 0.013
  txres@txFont                = "Helvetica-bold"
  txres@txJust = "TopRight"
  gsn_text_ndc(wks,time,0.75,0.89,txres)

  draw(plot)
  frame(wks)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
end

