load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRFUserARW.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

	begin

	SN = 135
	WE = 115

	BIAS = new((/SN,WE/),"float")
	RMSE = new((/SN,WE/),"float")

	PCC = 0.
	avgWRF = 0.
	avgRAR = 0.
	avgBias = 0.
	stdWRF = 0.
	stdRAR = 0.
	stdBias = 0.
	drmse = 0.

	BIAS@_FillValue = -9999.
	RMSE@_FillValue = -9999.

	PCC!0 = "spatial_average"
	avgWRF!0 = "spatial_average"
	avgRAR!0 = "spatial_average"
	avgBias!0 = "spatial_average"
	stdWRF!0 = "spatial_average"
	stdRAR!0 = "spatial_average"
	stdBias!0 = "spatial_average"
	drmse!0 = "spatial_average"


	BIAS!0 = "lat"
	BIAS!1 = "lon"
	RMSE!0 = "lat"
	RMSE!1 = "lon"

	BIAS@long_name = "bias"
	RMSE@long_name = "Mean Absolute Error"
	PCC@long_name = "Pearson's correlation coefficient"    
	avgWRF@long_name = "mean precipitation for WRF"
	avgRAR@long_name = "mean precipitation for RAR"
	stdWRF@long_name = "standard deviation of precipitation for WRF"
	stdRAR@long_name = "standard deviation of precipitation for RAR"
	avgBias@long_name = "spatial averaged Bias"
	stdBias@long_name = "standard deviation of Bias"
	drmse@long_name = "Root Mean Square Error"

	idir = "/home/sjpark/GA/exp_sokcho/RAR/output/5km_RAR/" ;;change
	widir = "/home/sjpark/GA/exp_sokcho/" ;;change

	fin = addfile(idir+"RAR_CAPPI_12hourly_ACCPREP_2018080512-0600_5km.nc","r")
	rar = fin->rar

 	ifil = "wrfout_d02_2018-08-06_00:00:00"
	bifil = "wrfout_d02_2018-08-05_12:00:00"

	a = addfile(widir+ifil,"r")
	b = addfile(widir+bifil,"r")

	times = wrf_user_getvar(a,"times",-1)  ; get all times in the file
	ntimes = dimsizes(times); number of times in the file
	it = 0
	print("Working on time: " + times(it) )
	time = times(it)
	rain = wrf_user_getvar(a,"RAINC",it)     ; Accumulated total cumulus precipitation (mm)
	crain = wrf_user_getvar(a,"RAINNC",it)     ; Accumulated total grid scale precipitation(mm)
	rain_plane = rain+crain
	brain = wrf_user_getvar(b,"RAINC",it)     ; Accumulated total cumulus precipitation (mm)
	bcrain = wrf_user_getvar(b,"RAINNC",it)     ; Accumulated total grid scale precipitation(mm)
	brain_plane = brain+bcrain
	rain_plane = rain_plane - brain_plane

	lat = wrf_user_getvar(a,"XLAT",it)      ; Latitude 
	lon = wrf_user_getvar(a,"XLONG",it)     ; Longitude 

	BIAS = 0.
	RMSE = 0.
        do j=0,SN-1
 		do i=0,WE-1
		    if rar(j,i) .gt. 0 then 
			if (ismissing(rar(j,i))) then 
				rar(j,i) = 0.
			end if
			BIAS(j,i) = rain_plane(j,i) - rar(j,i)
		        RMSE(j,i) = sqrt((rain_plane(j,i) - rar(j,i))^2.)
		    else
			BIAS(j,i) = BIAS@_FillValue
			RMSE(j,i) = RMSE@_FillValue
		    end if
		end do
	end do	
	printMinMax(BIAS,0)
	printMinMax(RMSE,0)

	A1 = 0.
	B1 = 0.
	B2 = 0.
	ncount = 0.
	drmse = 0.
        do j=0,SN-1
 		do i=0,WE-1
		    if rar(j,i) .gt. 0 then 
			A1 = A1 + (rain_plane(j,i) - avg(rain_plane))*(rar(j,i) - avg(rar))
			B1 = B1 + (rain_plane(j,i) - avg(rain_plane))^2
			B2 = B2 + (rar(j,i) - avg(rar))^2					
			drmse = BIAS(j,i)^2. + drmse
	 		ncount = ncount + 1.
		    end if
		end do
	end do        
  	PCC = A1/sqrt(B1*B2)
	avgWRF=avg(rain_plane)
	avgRAR=avg(rar)
        stdWRF=stddev(rain_plane)
        stdRAR=stddev(rar)
	avgBias=avg(BIAS)
        stdBias=stddev(BIAS)
	drmse = sqrt(drmse/ncount) 
	print(PCC)
	print(avgWRF)
	print(stdWRF)
	print(avgRAR)
	print(stdRAR)
	print(avgBias)
	print(stdBias)
	print(drmse)

	newname = "CTL-EXP-12hourly_statistics.nc"
	filnew = addfile(newname,"c")
	filnew->lat=lat
	filnew->lon=lon
	filnew->Bias=BIAS
	filnew->avgBias=avgBias
	filnew->stdBias=stdBias
	filnew->MAE=RMSE
	filnew->avgWRF=avgWRF
	filnew->stdWRF=stdWRF
	filnew->avgRAR=avgRAR
	filnew->stdRAR=stdRAR	
	filnew->RMSE=drmse
	filnew->PCC=PCC

    end
