;*************************************************
; scatter_4.ncl
;
; Concepts illustrated:
;   - Drawing a scatter plot with a regression line
;   - Drawing a time series plot
;   - Calculating the least squared regression for a one dimensional array
;   - Smoothing data so that seasonal cycle is less prominent
;   - Changing the markers in an XY plot
;   - Changing the marker color in an XY plot
;   - Changing the marker size in an XY plot
;
;*************************************************
;
; These files are loaded by default in NCL V6.2.0 and newer
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"

begin

   SN = 135
   WE = 115
   idir  = "/home/sjpark/GA/exp_sokcho/RAR/output/5km_RAR/"
   widir  = "/home/sjpark/GA_output/exp_sokcho/"
   
   data      = new ( (/2,SN*WE/), "float")
   model     = new ( (/SN*WE/), "float")
   
;*******************
; observation
        fin = addfile(idir+"RAR_CAPPI_12hourly_ACCPREP_2018080512-0600_5km.nc","r")
        rar = fin->rar
;*******************

;*******************
; 12-hour accumulated precip
	ifil = "wrfout_d02_2018-08-06_00:00:00"
        bifil = "wrfout_d02_2018-08-05_12:00:00"
        a = addfile(widir+ifil,"r")
        b = addfile(widir+bifil,"r")
;*******************

        times = wrf_user_getvar(a,"times",-1)  ; get all times in the file
        ntimes = dimsizes(times); number of times in the file
        it = 0
        print("Working on time: " + times(it) )
        time = times(it)
        rain = wrf_user_getvar(a,"RAINC",it)     ; Accumulated total cumulus precipitation (mm)
        crain = wrf_user_getvar(a,"RAINNC",it)     ; Accumulated total grid scale precipitation(mm)
        rain_plane = rain+crain
        brain = wrf_user_getvar(b,"RAINC",it)     ; Accumulated total cumulus precipitation (mm)
        bcrain = wrf_user_getvar(b,"RAINNC",it)     ; Accumulated total grid scale precipitation(mm)
        brain_plane = brain+bcrain
        rain_plane = rain_plane - brain_plane

;************************************************
; Create an array to hold both the original data
; and the calculated regression line.
;************************************************
       n=0
       do j=0,SN-1
         do i=0,WE-1
           if rar(j,i) .gt. 0 then 
             if (ismissing(rar(j,i))) then 
		rar(j,i) = 0.
	     end if
             data(0,n) = rar(j,i)
	     model(n) = rain_plane(j,i)
             n = n+1
           end if
         end do
       end do 
   data@_FillValue = -9999.
   model@_FillValue = -9999.

   rc    = regline(model,data(0,:))
; y = mx+b 
; m is the slope:       rc      returned from regline
; b is the y intercept: rc@yave attribute of rc returned from regline
   print(rc)
   data(1,:) = rc*(model-rc@xave) + rc@yave

;************************************************
; plotting parameters
;************************************************
   wks  = gsn_open_wks("png","scatter_12hourly_accprecip")             ; send graphics to PNG file
;************************************************
 
   res                     = True                   ; plot mods desired
   res@gsnDraw 		   = False
   res@gsnFrame 	   = False
   res@gsnMaximize         = True                   ; maximize plot in frame
   res@xyMarkLineModes     = (/"Markers","Lines"/)  ; choose which have markers
   res@xyMarkers           = 16                     ; choose type of marker 
   res@xyMarkerColor       = "blue"                  ; Marker color
   res@xyMarkerSizeF       = 0.005                  ; Marker size (default 0.01)
   res@xyDashPatterns      = 1                      ; solid line 
   res@xyLineThicknesses   = (/1,2/)                ; set second line to 2
   res@xyLineColor   = "red"                ; set second line to 2

   res@trYMinF = 0.
   res@trYMaxF = 100.
   res@trXMinF = 0.
   res@trXMaxF = 100.
   res@tiXAxisString	   = "Model"
   res@tiYAxisString	   = "Observaion-RAR"

   plot  = gsn_csm_xy (wks,model,data,res)        ; create plot
   
   res2 = True
   res2@gsnDraw = False
   res2@gsnFrame = False
   res2@xyLineThicknessF = 2
   res2@xyLineColor   = "black"                ; set second line to 2
   oplot  = gsn_csm_xy (wks,ispan(0,400,1),ispan(0,400,1),res2)        ; create plot

   overlay(plot,oplot)

   txres                       = True
   txres@txFontHeightF         = 0.013
   txres@txFont                = "Helvetica-bold"
   txres@txJust = "TopRight"
   gsn_text_ndc(wks,"R= "+rc,0.83,0.90,txres)

   draw(plot)
   frame(wks)

   delete(res)
   delete(res2)
   delete(txres)
   delete(plot)
   delete(oplot)
   delete(wks)
   delete(data)
   delete(model)

end
